<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="no" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+111"/>
      <source>Reverse Engineering</source>
      <translation>Reversertkonstruksjon</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Anslå flate...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Anslå en flate</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-62"/>
      <source>Reverse Engineering</source>
      <translation>Reversertkonstruksjon</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate surface...</source>
      <translation>Anslå overflate...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-Spline surface</source>
      <translation>Anslå en B-Splineoverflate</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Reversertkonstruksjon</translation>
    </message>
  </context>
</TS>
